# Generated by Django 5.2.5 on 2025-08-29 15:13

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0011_alter_projectversion_options_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='spidergroup',
            name='node',
            field=models.ForeignKey(db_constraint=False, default=1, on_delete=django.db.models.deletion.DO_NOTHING, to='django_scrapyd_manager.node', verbose_name='节点'),
            preserve_default=False,
        ),
    ]
