# Generated by Django 5.2.5 on 2025-08-27 19:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0005_spidergroup_kwargs_spidergroup_version_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='job',
            name='job_md5',
            field=models.CharField(default=1, max_length=32, unique=True, verbose_name='md5(job)'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='project',
            name='is_deleted',
            field=models.BooleanField(default=False, verbose_name='是否已被删除'),
        ),
        migrations.AddField(
            model_name='project',
            name='is_spider_synced',
            field=models.BooleanField(default=False, verbose_name='是否已同步当前版本爬虫'),
        ),
        migrations.AlterField(
            model_name='job',
            name='job_id',
            field=models.CharField(max_length=255, unique=True, verbose_name='任务ID'),
        ),
        migrations.AlterField(
            model_name='project',
            name='name',
            field=models.CharField(max_length=255, verbose_name='项目名'),
        ),
        migrations.AlterField(
            model_name='project',
            name='version',
            field=models.CharField(max_length=255, verbose_name='版本'),
        ),
        migrations.AlterField(
            model_name='spidergroup',
            name='description',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='任务组描述'),
        ),
    ]
