# Generated by Django 5.2.5 on 2025-08-19 11:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0003_alter_job_spider_alter_project_node_and_more'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='project',
            unique_together={('node', 'name', 'version')},
        ),
    ]
