# Generated by Django 5.2.5 on 2025-08-29 11:30

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0010_rename_project_spider_version_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='projectversion',
            options={'ordering': ['-version'], 'verbose_name': 'Scrapy Project Version', 'verbose_name_plural': 'Scrapy Project Version'},
        ),
        migrations.AlterField(
            model_name='projectversion',
            name='project',
            field=models.ForeignKey(db_constraint=False, on_delete=django.db.models.deletion.DO_NOTHING, related_name='versions', to='django_scrapyd_manager.project', verbose_name='项目'),
        ),
        migrations.AlterField(
            model_name='spidergroup',
            name='version',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='django_scrapyd_manager.projectversion', verbose_name='版本'),
        ),
    ]
