# Generated by Django 5.2.5 on 2025-08-27 19:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0006_job_job_md5_project_is_deleted_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='job_id',
            field=models.CharField(max_length=255, verbose_name='任务ID'),
        ),
    ]
