# Generated by Django 5.2.5 on 2025-08-27 17:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0004_alter_project_unique_together'),
    ]

    operations = [
        migrations.AddField(
            model_name='spidergroup',
            name='kwargs',
            field=models.JSONField(default=dict, verbose_name='参数'),
        ),
        migrations.AddField(
            model_name='spidergroup',
            name='version',
            field=models.CharField(default=1, max_length=100, verbose_name='版本'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='job',
            name='end_time',
            field=models.DateTimeField(blank=True, null=True, verbose_name='结束时间'),
        ),
        migrations.AlterField(
            model_name='job',
            name='start_time',
            field=models.DateTimeField(verbose_name='开始时间'),
        ),
        migrations.RemoveField(
            model_name='spidergroup',
            name='spiders',
        ),
        migrations.AddField(
            model_name='spidergroup',
            name='spiders',
            field=models.JSONField(default=list, verbose_name='爬虫'),
        ),
    ]
