# Generated by Django 5.2.5 on 2025-08-28 16:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0009_alter_project_unique_together_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='spider',
            old_name='project',
            new_name='version',
        ),
        migrations.AlterUniqueTogether(
            name='spider',
            unique_together={('version', 'name')},
        ),
    ]
