# Generated by Django 5.2.5 on 2025-08-28 11:50

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_scrapyd_manager', '0007_alter_job_job_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='spidergroup',
            name='nodes',
            field=models.ManyToManyField(db_constraint=False, to='django_scrapyd_manager.node', verbose_name='节点'),
        ),
        migrations.AlterField(
            model_name='job',
            name='spider',
            field=models.ForeignKey(db_constraint=False, on_delete=django.db.models.deletion.DO_NOTHING, related_name='jobs', to='django_scrapyd_manager.spider', verbose_name='爬虫'),
        ),
        migrations.AlterField(
            model_name='project',
            name='node',
            field=models.ForeignKey(db_constraint=False, on_delete=django.db.models.deletion.DO_NOTHING, related_name='projects', to='django_scrapyd_manager.node', verbose_name='节点'),
        ),
        migrations.AlterField(
            model_name='spider',
            name='project',
            field=models.ForeignKey(db_constraint=False, on_delete=django.db.models.deletion.DO_NOTHING, related_name='spiders', to='django_scrapyd_manager.project', verbose_name='项目'),
        ),
    ]
